@@ -4,9 +4,9 @@
 #
 # License: GPL 3, see file LICENSE
 #
-# Version: 20220623123946
-
+# Version: 20220716125655
 
+from inspect import signature
 class Sensor:
     sensorstates = {None, "ON", "OFF"}
 
@@ -16,7 +16,14 @@ class Sensor:
                 f"unknown sensor state {state}, not one of {Sensor.sensorstates}"
             )
         self.address = address
-        self.level = state
+        self.state = state
+
+    def toJSON(self):
+        return {
+            p: getattr(self, p)
+            for p in signature(self.__init__).parameters
+            if p != "self"
+        }
 
     def __str__(self):
-        return f"Sensor({self.address+1:2d}) = {'ON' if self.level else 'OFF'}"
+        return f"Sensor({self.address+1:2d}) = {'ON' if self.state else 'OFF'}"
